@@ -12,7 +12,7 @@ use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
 use PPIx::QuoteLike::Utils qw{ __instance };
 use Scalar::Util ();
 
-our $VERSION = '0.010_04';
+our $VERSION = '0.010_05';
 
 use constant SCALAR_REF	=> ref \0;
 
@@ -269,17 +269,6 @@ __END_OF_HERE_DOCUMENT
 ";
     }
 
-=begin comment
-
-    $val =~ m/ [{}] /smx
-	or return "q{$val}";
-    $val =~ m{ / }smx
-	or return "q/$val/";
-
-=end comment
-
-=cut
-
     $val =~ s/ (?= [\\'] )/\\/smxg;
     return "'$val'";
 }
